@@ -1,7 +1,5 @@
 # noqa: D100
-import numpy as np
 import pandas as pd
-import pytest
 
 from nowcasting_dataset import utils
 
@@ -16,20 +14,6 @@ def test_is_monotically_increasing():  # noqa: D103
     assert not utils.is_monotonically_increasing(index[::-1])
 
 
-def test_sin_and_cos():  # noqa: D103
-    df = pd.DataFrame({"a": range(30), "b": np.arange(30) - 30})
-    with pytest.raises(ValueError) as _:
-        utils.sin_and_cos(pd.DataFrame({"a": [-1, 0, 1]}))
-    with pytest.raises(ValueError) as _:
-        utils.sin_and_cos(pd.DataFrame({"a": [0, 1, 2]}))
-    with pytest.raises(ValueError) as _:
-        utils.sin_and_cos(df)
-
-    rescaled = utils.scale_to_0_to_1(df)
-    sin_and_cos = utils.sin_and_cos(rescaled)
-    np.testing.assert_array_equal(sin_and_cos.columns, ["a_sin", "a_cos", "b_sin", "b_cos"])
-
-
 def test_get_netcdf_filename():  # noqa: D103
     assert utils.get_netcdf_filename(10) == "000010.nc"
 
